"""django-vanillaframework test utilities."""
import shutil
from pathlib import Path

BASE_DIR = Path(__file__).resolve().parent.parent


def clean_test_files():
    """Clean files generated by tests."""
    try:
        shutil.rmtree(BASE_DIR / "static")
    except FileNotFoundError:
        pass
